# Generated by Django 4.2.10 on 2024-03-06 09:29

import wbcore.models.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("wbhuman_resources", "0019_alter_absencerequest_options_alter_kpi_options_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="employeeyearbalance",
            name="year",
            field=wbcore.models.fields.YearField(verbose_name="Year"),
        ),
        migrations.AlterField(
            model_name="review",
            name="year",
            field=wbcore.models.fields.YearField(blank=True, null=True, verbose_name="Year"),
        ),
        migrations.RemoveField(
            model_name="position",
            name="is_internal",
        ),
    ]
